@@ -1,22 +1,10 @@
-/*****************************************************************************
- * Copyright (c) 2007 Piyush verma <piyush.verma@gmail.com>                  *
- * Copyright 2007 Andreas Pakulat <apaku@gmx.de>                             *
- * Copyright 2010-2013 Sven Brauch <svenbrauch@googlemail.com>               *
- *                                                                           *
- * This program is free software; you can redistribute it and/or             *
- * modify it under the terms of the GNU General Public License as            *
- * published by the Free Software Foundation; either version 2 of            *
- * the License, or (at your option) any later version.                       *
- *                                                                           *
- * This program is distributed in the hope that it will be useful,           *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
- * GNU General Public License for more details.                              *
- *                                                                           *
- * You should have received a copy of the GNU General Public License         *
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
- *****************************************************************************
- */
+/*
+    SPDX-FileCopyrightText: 2007 Piyush verma <piyush.verma@gmail.com>
+    SPDX-FileCopyrightText: 2007 Andreas Pakulat <apaku@gmx.de>
+    SPDX-FileCopyrightText: 2010-2013 Sven Brauch <svenbrauch@googlemail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "pythonlanguagesupport.h"
 #include "pythoneditorintegrator.h"
@@ -53,8 +41,10 @@ using namespace KTextEditor;
 namespace Python
 {
 
-ReferencedTopDUContext ContextBuilder::build(const IndexedString& url, Ast* node, ReferencedTopDUContext updateContext)
+ReferencedTopDUContext ContextBuilder::build(const IndexedString& url, Ast* node,
+                                             const ReferencedTopDUContext& updateContext_)
 {
+    ReferencedTopDUContext updateContext(updateContext_);
     if (!updateContext) {
         DUChainReadLocker lock(DUChain::lock());
         updateContext = DUChain::self()->chainForDocument(url);
@@ -295,8 +285,7 @@ void ContextBuilder::visitClassDefinition( ClassDefinitionAst* node )
 }
 
 void ContextBuilder::visitCode(CodeAst* node) {
-    auto doc_url = Helper::getDocumentationFile();
-    IndexedString doc = IndexedString(doc_url);
+    IndexedString doc = Helper::getDocumentationFile();
     Q_ASSERT(currentlyParsedDocument().toUrl().isValid());
     if ( currentlyParsedDocument() != doc ) {
         // Search for the python built-in functions file, and dump its contents into the current file.
@@ -306,7 +295,7 @@ void ContextBuilder::visitCode(CodeAst* node) {
             m_unresolvedImports.append(doc);
             KDevelop::ICore::self()->languageController()->backgroundParser()
                                    ->addDocument(doc, KDevelop::TopDUContext::ForceUpdate,
-                                                 BackgroundParser::BestPriority*2, 0, ParseJob::FullSequentialProcessing);
+                                                 BackgroundParser::BestPriority*2, nullptr, ParseJob::FullSequentialProcessing);
             // This must NOT be called from parse threads! It's only meant to be used from the foreground thread, and will
             // cause thread starvation if called from here.
             // KDevelop::ICore::self()->languageController()->backgroundParser()->parseDocuments();
@@ -396,6 +385,13 @@ QPair<QUrl, QStringList> ContextBuilder::findModulePath(const QString& name, con
     return {};
 }
 
+void ContextBuilder::visitLambda(LambdaAst* node)
+{
+    openContext(node, editorFindRange(node, node->body), DUContext::Other);
+    AstDefaultVisitor::visitLambda(node);
+    closeContext();
+}
+
 RangeInRevision ContextBuilder::rangeForArgumentsContext(FunctionDefinitionAst* node)
 {
     auto start = node->name->range().end();
