@@ -1,24 +1,8 @@
 /*
- * This file is part of kdev-python, the Python language support plugin for KDevelop
- * Copyright 2013  Sven Brauch <svenbrauch@gmail.com>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- */
+    SPDX-FileCopyrightText: 2013 Sven Brauch <svenbrauch@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #include "correctionhelper.h"
 #include "helpers.h"
@@ -40,7 +24,7 @@ namespace Python {
 
 CorrectionHelper::CorrectionHelper(const IndexedString& _url, DeclarationBuilder* builder)
 {
-    m_contextStack.push(0);
+    m_contextStack.push(nullptr);
     auto absolutePath = Helper::getCorrectionFile(_url.toUrl());
 
     if ( !absolutePath.isValid() || absolutePath.isEmpty() || ! QFile::exists(absolutePath.path()) ) {
@@ -71,7 +55,7 @@ void CorrectionHelper::enter(const KDevelop::Identifier& identifier)
     DUContext* current = m_contextStack.top();
     if ( ! current ) {
         // no hints for the parent object, so no hints for its children either
-        m_contextStack.push(0);
+        m_contextStack.push(nullptr);
         return;
     }
 
@@ -79,7 +63,7 @@ void CorrectionHelper::enter(const KDevelop::Identifier& identifier)
     const QList<Declaration*> decls = current->findDeclarations(identifier);
     if ( decls.isEmpty() ) {
         // no hints for the current object
-        m_contextStack.push(0);
+        m_contextStack.push(nullptr);
         return;
     }
 
